# uitext
Contains 
- html2ascii: Utility for turning an HTML page into an ASCII-art version, for comparison in TextTest tests
- selenium_utils.py: Utility code for testing a web UI with Selenium and dumping out the DOM for use with the above
- sikuli/: Code for visual UI testing using Sikuli and using Multilocators

## usage
To use this script:

    python html2ascii.py --help

